@@ -10,11 +10,12 @@
 
 from .ext import InvenioOAuthClient, InvenioOAuthClientREST
 from .proxies import current_oauthclient
-from .version import __version__
+
+__version__ = "2.1.0"
 
 __all__ = (
-    '__version__',
-    'current_oauthclient',
-    'InvenioOAuthClient',
-    'InvenioOAuthClientREST'
+    "__version__",
+    "current_oauthclient",
+    "InvenioOAuthClient",
+    "InvenioOAuthClientREST",
 )
