@@ -11,6 +11,4 @@
 from flask import current_app
 from werkzeug.local import LocalProxy
 
-current_oauthclient = LocalProxy(
-    lambda: current_app.extensions['invenio-oauthclient']
-)
+current_oauthclient = LocalProxy(lambda: current_app.extensions["invenio-oauthclient"])
