@@ -16,8 +16,11 @@ from flask import url_for
 from flask_login import current_user
 from flask_security import login_user
 from flask_security.utils import hash_password
-from helpers import check_redirect_location, \
-    check_response_redirect_url_args, mock_response
+from helpers import (
+    check_redirect_location,
+    check_response_redirect_url_args,
+    mock_response,
+)
 from invenio_accounts.models import User
 from invenio_db import db
 from six.moves.urllib_parse import parse_qs, urlparse
@@ -31,8 +34,13 @@ from invenio_oauthclient.views.client import serializer
 
 
 def _get_state():
-    return serializer.dumps({'app': 'github', 'sid': _create_identifier(),
-                             'next': None, })
+    return serializer.dumps(
+        {
+            "app": "github",
+            "sid": _create_identifier(),
+            "next": None,
+        }
+    )
 
 
 def test_login(app_rest):
@@ -40,17 +48,16 @@ def test_login(app_rest):
     client = app_rest.test_client()
 
     resp = client.get(
-        url_for('invenio_oauthclient.rest_login', remote_app='github',
-                next='/someurl/')
+        url_for("invenio_oauthclient.rest_login", remote_app="github", next="/someurl/")
     )
     assert resp.status_code == 302
 
     params = parse_qs(urlparse(resp.location).query)
-    assert params['response_type'], ['code']
-    assert params['scope'] == ['user,user:email']
-    assert params['redirect_uri']
-    assert params['client_id']
-    assert params['state']
+    assert params["response_type"], ["code"]
+    assert params["scope"] == ["user,user:email"]
+    assert params["redirect_uri"]
+    assert params["client_id"]
+    assert params["state"]
 
 
 class MockGh(object):
@@ -62,40 +69,43 @@ class MockGh(object):
 
     def emails(self):
         """Get emails."""
-        Email = namedtuple('Email', 'verified primary email')
-        yield Email(verified=True, primary=True,
-                    email=self._email)
+        Email = namedtuple("Email", "verified primary email")
+        yield Email(verified=True, primary=True, email=self._email)
 
     def me(self):
         """Mock me."""
-        Me = namedtuple('Me', 'id name login')
-        return Me(id='githubuser', name='John', login='mynick')
+        Me = namedtuple("Me", "id name login")
+        return Me(id="githubuser", name="John", login="mynick")
 
 
 def test_authorized_signup_valid_user(app_rest, example_github):
     """Test authorized callback with sign-up."""
-    example_email = 'info@inveniosoftware.org'
+    example_email = "info@inveniosoftware.org"
 
     with app_rest.test_client() as c:
         # User login with email 'info'
-        with mock.patch('github3.login') as MockLogin:
-            MockLogin.return_value = MockGh(email='info@inveniosoftware.org')
+        with mock.patch("github3.login") as MockLogin:
+            MockLogin.return_value = MockGh(email="info@inveniosoftware.org")
 
             # Ensure remote apps have been loaded (due to before first
             # request)
-            resp = c.get(url_for('invenio_oauthclient.rest_login',
-                                 remote_app='github'))
+            resp = c.get(url_for("invenio_oauthclient.rest_login", remote_app="github"))
 
             assert resp.status_code == 302
 
-            mock_response(app_rest.extensions['oauthlib.client'], 'github',
-                          example_github)
+            mock_response(
+                app_rest.extensions["oauthlib.client"], "github", example_github
+            )
 
             # User authorized the requests and is redirect back
             resp = c.get(
-                url_for('invenio_oauthclient.rest_authorized',
-                        remote_app='github', code='test',
-                        state=_get_state()))
+                url_for(
+                    "invenio_oauthclient.rest_authorized",
+                    remote_app="github",
+                    code="test",
+                    state=_get_state(),
+                )
+            )
             assert resp.status_code == 302
             expected_url_args = {
                 "message": "Successfully authorized.",
@@ -108,22 +118,22 @@ def test_authorized_signup_valid_user(app_rest, example_github):
             remote = RemoteAccount.query.filter_by(user_id=user.id).one()
             RemoteToken.query.filter_by(id_remote_account=remote.id).one()
             assert user.active
+            assert user.confirmed_at
 
             # Disconnect link
             # should not work, because it's the user's only means of login
             resp = c.get(
-                url_for(
-                    'invenio_oauthclient.rest_disconnect',
-                    remote_app='github'
-                )
+                url_for("invenio_oauthclient.rest_disconnect", remote_app="github")
             )
             assert resp.status_code == 400
 
             user = User.query.filter_by(email=example_email).one()
-            assert 1 == UserIdentity.query.filter_by(
-                method='github', id_user=user.id,
-                id='githubuser'
-            ).count()
+            assert (
+                1
+                == UserIdentity.query.filter_by(
+                    method="github", id_user=user.id, id="githubuser"
+                ).count()
+            )
 
             # set a password for the user
             user.password = hash_password("1234")
@@ -131,29 +141,34 @@ def test_authorized_signup_valid_user(app_rest, example_github):
 
             # Disconnect again
             resp = c.get(
-                url_for(
-                    'invenio_oauthclient.rest_disconnect',
-                    remote_app='github'))
+                url_for("invenio_oauthclient.rest_disconnect", remote_app="github")
+            )
             assert resp.status_code == 302
 
             # User exists
             user = User.query.filter_by(email=example_email).one()
-            assert 0 == UserIdentity.query.filter_by(
-                method='github', id_user=user.id,
-                id='githubuser'
-            ).count()
+            assert (
+                0
+                == UserIdentity.query.filter_by(
+                    method="github", id_user=user.id, id="githubuser"
+                ).count()
+            )
             assert RemoteAccount.query.filter_by(user_id=user.id).count() == 0
             assert RemoteToken.query.count() == 0
 
         # User login with another email ('info2')
-        with mock.patch('github3.login') as MockLogin:
-            MockLogin.return_value = MockGh(email='info2@inveniosoftware.org')
+        with mock.patch("github3.login") as MockLogin:
+            MockLogin.return_value = MockGh(email="info2@inveniosoftware.org")
 
             # User authorized the requests and is redirect back
             resp = c.get(
-                url_for('invenio_oauthclient.rest_authorized',
-                        remote_app='github', code='test',
-                        state=_get_state()))
+                url_for(
+                    "invenio_oauthclient.rest_authorized",
+                    remote_app="github",
+                    code="test",
+                    state=_get_state(),
+                )
+            )
             assert resp.status_code == 302
             check_response_redirect_url_args(resp, expected_url_args)
 
@@ -162,47 +177,49 @@ def test_authorized_signup_valid_user(app_rest, example_github):
             assert user.email == example_email
 
 
-def test_authorized_signup_username_already_exists(
-                                                    app_rest, example_github,
-                                                    user_rest):
+def test_authorized_signup_username_already_exists(app_rest, example_github, user_rest):
     """Test authorized callback with sign-up."""
-    example_email = 'another@email.it'
+    example_email = "another@email.it"
 
     with app_rest.test_client() as c:
         # User login with email 'info'
-        with mock.patch('github3.login') as MockLogin:
+        with mock.patch("github3.login") as MockLogin:
             MockLogin.return_value = MockGh(email=example_email)
 
             # Ensure remote apps have been loaded (due to before first
             # request)
-            resp = c.get(url_for('invenio_oauthclient.rest_login',
-                                 remote_app='github'))
+            resp = c.get(url_for("invenio_oauthclient.rest_login", remote_app="github"))
 
             assert resp.status_code == 302
 
-            mock_response(app_rest.extensions['oauthlib.client'], 'github',
-                          example_github)
+            mock_response(
+                app_rest.extensions["oauthlib.client"], "github", example_github
+            )
 
             # User authorized the requests and is redirect back
             resp = c.get(
-                url_for('invenio_oauthclient.rest_authorized',
-                        remote_app='github', code='test',
-                        state=_get_state()))
+                url_for(
+                    "invenio_oauthclient.rest_authorized",
+                    remote_app="github",
+                    code="test",
+                    state=_get_state(),
+                )
+            )
             assert resp.status_code == 302
             assert resp.location == (
-                'http://localhost' +
-                url_for('invenio_oauthclient.rest_signup', remote_app='github')
+                url_for("invenio_oauthclient.rest_signup", remote_app="github")
             )
 
             # User fills form to register
             resp = c.post(
-                resp.headers['Location'],
+                resp.headers["Location"],
                 data={
-                    'email': example_email,
-                    'password': '123456',
-                    'profile.username': 'pippo2',
-                    'profile.full_name': 'pluto',
-                }
+                    "email": example_email,
+                    "password": "123456",
+                    "profile.username": "pippo2",
+                    "profile.full_name": "pluto",
+                    "profile.affiliations": "CERN",
+                },
             )
             assert resp.status_code == 200
             expected_json = {
@@ -220,18 +237,17 @@ def test_authorized_signup_username_already_exists(
             # Disconnect link
             # should not work, because it's the user's only means of login
             resp = c.get(
-                url_for(
-                    'invenio_oauthclient.rest_disconnect',
-                    remote_app='github'
-                )
+                url_for("invenio_oauthclient.rest_disconnect", remote_app="github")
             )
             assert resp.status_code == 400
 
             my_user = User.query.filter_by(email=example_email).one()
-            assert 1 == UserIdentity.query.filter_by(
-                method='github', id_user=my_user.id,
-                id='githubuser'
-            ).count()
+            assert (
+                1
+                == UserIdentity.query.filter_by(
+                    method="github", id_user=my_user.id, id="githubuser"
+                ).count()
+            )
 
             # set a password for the user
             my_user.password = hash_password("1234")
@@ -239,18 +255,18 @@ def test_authorized_signup_username_already_exists(
 
             # Disconnect again
             resp = c.get(
-                url_for(
-                    'invenio_oauthclient.rest_disconnect',
-                    remote_app='github'))
+                url_for("invenio_oauthclient.rest_disconnect", remote_app="github")
+            )
             assert resp.status_code == 302
 
             my_user = User.query.filter_by(email=example_email).one()
-            assert 0 == UserIdentity.query.filter_by(
-                method='github', id_user=my_user.id,
-                id='githubuser'
-            ).count()
-            assert RemoteAccount.query.filter_by(
-                user_id=my_user.id).count() == 0
+            assert (
+                0
+                == UserIdentity.query.filter_by(
+                    method="github", id_user=my_user.id, id="githubuser"
+                ).count()
+            )
+            assert RemoteAccount.query.filter_by(user_id=my_user.id).count() == 0
             assert RemoteToken.query.count() == 0
             # assert User.query.count() == 2
 
@@ -258,12 +274,16 @@ def test_authorized_signup_username_already_exists(
 def test_authorized_reject(app_rest):
     """Test a rejected request."""
     with app_rest.test_client() as c:
-        c.get(url_for('invenio_oauthclient.rest_login', remote_app='github'))
+        c.get(url_for("invenio_oauthclient.rest_login", remote_app="github"))
         resp = c.get(
-            url_for('invenio_oauthclient.rest_authorized',
-                    remote_app='github', error='access_denied',
-                    error_description='User denied access',
-                    state=_get_state()))
+            url_for(
+                "invenio_oauthclient.rest_authorized",
+                remote_app="github",
+                error="access_denied",
+                error_description="User denied access",
+                state=_get_state(),
+            )
+        )
         assert resp.status_code in (301, 302)
         expected_url_args = {
             "message": "You rejected the authentication request.",
@@ -272,53 +292,59 @@ def test_authorized_reject(app_rest):
         check_response_redirect_url_args(resp, expected_url_args)
 
 
-def test_authorized_already_authenticated(app_rest, models_fixture,
-                                          example_github):
+def test_authorized_already_authenticated(app_rest, models_fixture, example_github):
     """Test authorized callback with sign-up."""
-    datastore = app_rest.extensions['invenio-accounts'].datastore
+    datastore = app_rest.extensions["invenio-accounts"].datastore
     login_manager = app_rest.login_manager
 
-    existing_email = 'existing@inveniosoftware.org'
+    existing_email = "existing@inveniosoftware.org"
     user = datastore.find_user(email=existing_email)
 
     @login_manager.user_loader
     def load_user(user_id):
         return user
 
-    @app_rest.route('/foo_login')
+    @app_rest.route("/foo_login")
     def login():
         login_user(user)
-        return 'Logged In'
+        return "Logged In"
 
-    with mock.patch('github3.login') as MockLogin:
-        MockLogin.return_value = MockGh(email='info@inveniosoftware.org')
+    with mock.patch("github3.login") as MockLogin:
+        MockLogin.return_value = MockGh(email="info@inveniosoftware.org")
 
         with app_rest.test_client() as client:
 
             # make a fake login (using my login function)
-            client.get('/foo_login', follow_redirects=True)
+            client.get("/foo_login", follow_redirects=True)
 
             # Ensure remote apps have been loaded (due to before first
             # request)
-            client.get(url_for('invenio_oauthclient.rest_login',
-                               remote_app='github'))
+            client.get(url_for("invenio_oauthclient.rest_login", remote_app="github"))
 
             # Mock access token request
-            mock_response(app_rest.extensions['oauthlib.client'], 'github',
-                          example_github)
+            mock_response(
+                app_rest.extensions["oauthlib.client"], "github", example_github
+            )
 
             # User then goes to 'Linked accounts' and clicks 'Connect'
             resp = client.get(
-                url_for('invenio_oauthclient.rest_login', remote_app='github',
-                        next='/someurl/')
+                url_for(
+                    "invenio_oauthclient.rest_login",
+                    remote_app="github",
+                    next="/someurl/",
+                )
             )
             assert resp.status_code == 302
 
             # User authorized the requests and is redirected back
             resp = client.get(
-                url_for('invenio_oauthclient.rest_authorized',
-                        remote_app='github', code='test',
-                        state=_get_state()))
+                url_for(
+                    "invenio_oauthclient.rest_authorized",
+                    remote_app="github",
+                    code="test",
+                    state=_get_state(),
+                )
+            )
 
             # Assert database state (Sign-up complete)
             u = User.query.filter_by(email=existing_email).one()
@@ -327,17 +353,18 @@ def test_authorized_already_authenticated(app_rest, models_fixture,
 
             # Disconnect link
             resp = client.get(
-                url_for(
-                    'invenio_oauthclient.rest_disconnect',
-                    remote_app='github'))
+                url_for("invenio_oauthclient.rest_disconnect", remote_app="github")
+            )
             assert resp.status_code == 302
 
             # User exists
             u = User.query.filter_by(email=existing_email).one()
-            assert 0 == UserIdentity.query.filter_by(
-                method='github', id_user=u.id,
-                id='githubuser'
-            ).count()
+            assert (
+                0
+                == UserIdentity.query.filter_by(
+                    method="github", id_user=u.id, id="githubuser"
+                ).count()
+            )
             assert RemoteAccount.query.filter_by(user_id=u.id).count() == 0
             assert RemoteToken.query.count() == 0
 
@@ -347,18 +374,17 @@ def test_not_authenticated(app_rest):
     with app_rest.test_client() as client:
         assert not current_user.is_authenticated
         resp = client.get(
-            url_for(
-                'invenio_oauthclient.rest_disconnect',
-                remote_app='github'))
+            url_for("invenio_oauthclient.rest_disconnect", remote_app="github")
+        )
         assert resp.status_code == 302
 
 
 def test_authorized_rest_handler(app_rest):
     """Test authorized callback handler."""
     oauth = current_oauthclient.oauth
-    remote = oauth.remote_apps['github']
+    remote = oauth.remote_apps["github"]
     # General error
-    example_response = {'error': 'error'}
+    example_response = {"error": "error"}
     resp = authorized_rest(example_response, remote)
     expected_url_args = {
         "message": "Authorization with remote service failed.",
@@ -366,16 +392,16 @@ def test_authorized_rest_handler(app_rest):
     }
     check_response_redirect_url_args(resp, expected_url_args)
     # Bad verification error
-    example_response = {'error': 'bad_verification_code'}
+    example_response = {"error": "bad_verification_code"}
     resp = authorized_rest(example_response, remote)
-    check_redirect_location(resp, '/oauth/login/github/')
+    check_redirect_location(resp, "/oauth/login/github/")
 
     # Incorrect client credentials
-    example_response = {'error': 'incorrect_client_credentials'}
+    example_response = {"error": "incorrect_client_credentials"}
     with pytest.raises(OAuthResponseError):
         authorized_rest(example_response, remote)
 
         # Redirect uri mismatch
-        example_response = {'error': 'redirect_uri_mismatch'}
+        example_response = {"error": "redirect_uri_mismatch"}
         with pytest.raises(OAuthResponseError):
             authorized_rest(example_response, remote)
